"""Translation of IDs with flexible formatting and name matching."""
from rics.translation._translator import Translator
from rics.translation.factory import TranslatorFactory

__all__ = ["Translator", "TranslatorFactory"]
